import {Sample} from '../types/Sample';
import {Backend} from './Backend';

export class LongPlaytimeFilteringBackend implements Backend {
  private backend: Backend;

  constructor(next: Backend) {
    this.backend = next;
  }

  public sendRequest(sample: Sample) {
    if (this.isPlayedAboveThreshold(sample)) {
      return;
    }
    this.backend.sendRequest(sample);
  }

  public sendUnloadRequest(sample: Sample) {
    if (this.isPlayedAboveThreshold(sample)) {
      return;
    }
    this.backend.sendUnloadRequest(sample);
  }

  public sendRequestSynchronous(sample: Sample) {
    if (this.isPlayedAboveThreshold(sample)) {
      return;
    }
    this.backend.sendRequestSynchronous(sample);
  }

  public sendAdRequest(sample: any) {
    this.backend.sendAdRequest(sample);
  }

  private isPlayedAboveThreshold(sample: Sample): boolean {
    return (sample.played == null ? 0 : sample.played) >= 90000;
  }
}
