#!/bin/bash

notify_api () {
  VERSION=$1
  URL=$2
  curl "https://api.bitmovin.com/v1/admin/analytics/releases/web/v$VERSION" -H "X-Api-Key:e5ed03fc-419b-4a07-9298-a4899ff160a2" -H "Content-Type:application/json" --data-binary "{\"cdnUrl\": \"$URL\",\"npmName\":\"bitmovin-analytics@$VERSION\"}" > /dev/null 2>&1
  if [ $? -eq 0 ]; then
    echo "Published Release $VERSION @ $URL to Bitmovin API"
  else
    echo "Failed to publish release to Bitmovin API"
  fi
}

echo "Running fresh build"
yarn build:release > /dev/null 2>&1

BASEPATH="gs://cloudflare-cdn-origin-bucket/analytics/web"
VERSION=`git describe`
if [[ $VERSION =~ ^v[0-9]+\.[0-9]+\.[0-9]+ ]] 
then
  FULL=$(git describe | cut -c 2-)
  MAJOR=$(echo $FULL | cut -d'.' -f1)
  MINOR=$(echo $FULL | cut -d'.' -f2)
  REVISION=$(echo $FULL | cut -d'.' -f3) # Not needed right now

  echo "Version matches release tag: $FULL - publishing to CDN"
  mkdir -p ./build/$FULL/
  cp ./build/release/bitmovinanalytics.min.js ./build/$FULL/
  cp ./build/release/bitmovinanalytics.min.js.map ./build/$FULL/

  if [[ $VERSION =~ ^v[0-9]+\.[0-9]+\.[0-9]+-rc[0-9]+$ ]] 
  then
    echo "Deploying $FULL to /web/staging/$FULL"
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js $BASEPATH/staging/$FULL/bitmovinanalytics.min.js > /dev/null 2>&1
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js.map $BASEPATH/staging/$FULL/bitmovinanalytics.min.js.map > /dev/null 2>&1
    echo "Deploying $FULL to /web/staging/$MAJOR"
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js $BASEPATH/staging/$MAJOR/bitmovinanalytics.min.js > /dev/null 2>&1
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js.map $BASEPATH/staging/$MAJOR/bitmovinanalytics.min.js.map > /dev/null 2>&1
    echo "Deploying $FULL to /web/staging/$MAJOR.$MINOR"
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js $BASEPATH/staging/$MAJOR.$MINOR/bitmovinanalytics.min.js > /dev/null 2>&1
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js.map $BASEPATH/staging/$MAJOR.$MINOR/bitmovinanalytics.min.js.map > /dev/null 2>&1

    echo "CDN URLs for STAGING"
    echo "[  direct  ] https://cdn.bitmovin.com/analytics/web/staging/$FULL/bitmovinanalytics.min.js"
    echo "[  major   ] https://cdn.bitmovin.com/analytics/web/staging/$MAJOR/bitmovinanalytics.min.js"
    echo "[  minor   ] https://cdn.bitmovin.com/analytics/web/staging/$MAJOR.$MINOR/bitmovinanalytics.min.js"

    notify_api $FULL "https://cdn.bitmovin.com/analytics/web/staging/$FULL/bitmovinanalytics.min.js"
  fi

  if [[ $VERSION =~ ^v[0-9]+\.[0-9]+\.[0-9]+-(rc|beta)[0-9]+$ ]] 
  then
    echo "Deploying $FULL to /web/beta/$FULL"
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js $BASEPATH/beta/$FULL/bitmovinanalytics.min.js > /dev/null 2>&1
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js.map $BASEPATH/beta/$FULL/bitmovinanalytics.min.js.map > /dev/null 2>&1
    echo "Deploying $FULL to /web/beta/$MAJOR"
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js $BASEPATH/beta/$MAJOR/bitmovinanalytics.min.js > /dev/null 2>&1
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js.map $BASEPATH/beta/$MAJOR/bitmovinanalytics.min.js.map > /dev/null 2>&1
    echo "Deploying $FULL to /web/beta/$MAJOR.$MINOR"
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js $BASEPATH/beta/$MAJOR.$MINOR/bitmovinanalytics.min.js > /dev/null 2>&1
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js.map $BASEPATH/beta/$MAJOR.$MINOR/bitmovinanalytics.min.js.map > /dev/null 2>&1

    echo "CDN URLs for BETA:"
    echo "[  direct  ] https://cdn.bitmovin.com/analytics/web/beta/$FULL/bitmovinanalytics.min.js"
    echo "[  major   ] https://cdn.bitmovin.com/analytics/web/beta/$MAJOR/bitmovinanalytics.min.js"
    echo "[  minor   ] https://cdn.bitmovin.com/analytics/web/beta/$MAJOR.$MINOR/bitmovinanalytics.min.js"

    notify_api $FULL "https://cdn.bitmovin.com/analytics/web/beta/$FULL/bitmovinanalytics.min.js"
  fi

  if [[ $VERSION =~ ^v[0-9]+\.[0-9]+\.[0-9]+$ ]] 
  then
    echo "Deploying $FULL to /web/$FULL"
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js $BASEPATH/$FULL/bitmovinanalytics.min.js > /dev/null 2>&1
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js.map $BASEPATH/$FULL/bitmovinanalytics.min.js.map > /dev/null 2>&1
    echo "Deploying $FULL to /web/$MAJOR"
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js $BASEPATH/$MAJOR/bitmovinanalytics.min.js > /dev/null 2>&1
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js.map $BASEPATH/$MAJOR/bitmovinanalytics.min.js.map > /dev/null 2>&1
    echo "Deploying $FULL to /web/$MAJOR.$MINOR"
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js $BASEPATH/$MAJOR.$MINOR/bitmovinanalytics.min.js > /dev/null 2>&1
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js.map $BASEPATH/$MAJOR.$MINOR/bitmovinanalytics.min.js.map > /dev/null 2>&1

    echo "CDN URLs:"
    echo "[  direct  ] https://cdn.bitmovin.com/analytics/web/$FULL/bitmovinanalytics.min.js"
    echo "[  major   ] https://cdn.bitmovin.com/analytics/web/$MAJOR/bitmovinanalytics.min.js"
    echo "[  minor   ] https://cdn.bitmovin.com/analytics/web/$MAJOR.$MINOR/bitmovinanalytics.min.js"

    notify_api $FULL "https://cdn.bitmovin.com/analytics/web/$FULL/bitmovinanalytics.min.js"
  else 
    echo "Deploying $FULL to /web/$FULL"
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js $BASEPATH/$FULL/bitmovinanalytics.min.js > /dev/null 2>&1
    gsutil cp -a public-read ./build/$FULL/bitmovinanalytics.min.js.map $BASEPATH/$FULL/bitmovinanalytics.min.js.map > /dev/null 2>&1

    echo "Version $FULL is not a full release - not publishing major/minor shortversions"
    echo "CDN URLs:"
    echo "[  direct  ] https://cdn.bitmovin.com/analytics/web/$FULL/bitmovinanalytics.min.js"
    exit 0
  fi
fi
