  
#!/bin/bash
set -eu

#check if we have the codeship branch variable available and fail otherwise
if [ -z "$CI_BRANCH" ]; then
  echo "Error no branch set"
  exit 1
fi

BRANCH_PR=""
#hotfix and release-branches will have the master as their target
if [[ "${CI_BRANCH}" == hotfix* ]] || [[ "${CI_BRANCH}" == release* ]]; then
  BRANCH_PR="master"
  echo "Analyzing branch: ${CI_BRANCH} which has the target branch: master"
elif [[ "${CI_BRANCH}" == "master" ]]; then #master has no target
  echo "Analyzing branch: ${CI_BRANCH} which has no target branch"
elif [[ "${CI_BRANCH}" == "develop" ]]; then #develop has no target
  echo "Analyzing branch: ${CI_BRANCH} which has no target branch"
else #every branch that is not a hotfix or release branch (e.g. feature/...) has develop as it's target.
  BRANCH_PR="develop"
  echo "Analyzing branch: ${CI_BRANCH} which has the target-branch: develop"
fi

GH_API_URL="https://api.github.com/repos/bitmovin/${CI_REPO_NAME}/pulls?state=open&head=bitmovin:${CI_BRANCH}"
AUTH_HEADER="Authorization: token ${GH_TOKEN}"
PR_NUMBER="$(curl -sS -H "${AUTH_HEADER}" "${GH_API_URL}" | jq '.[] .number')"

yarn run coverage

if [[ -z "$PR_NUMBER" ]]; then
  echo "Starting branch analysis for ${CI_BRANCH} with target ${BRANCH_PR} ${PR_NUMBER}"
  node sonar-analysis.js BRANCH $CI_BRANCH $BRANCH_PR
  echo "Finished branchanalysis for ${CI_BRANCH} with target ${BRANCH_PR} ${PR_NUMBER}"
else
  echo "Starting pull request analysis for ${CI_BRANCH} with target ${BRANCH_PR} ${PR_NUMBER}"
  node sonar-analysis.js PR $CI_BRANCH $PR_NUMBER $BRANCH_PR $CI_REPO_NAME
  # /programs/sonar-scanner-3.2.0.1227-linux/bin/sonar-scanner -Dsonar.pullrequest.branch="${CI_BRANCH}" -Dsonar.pullrequest.key="${PR_NUMBER}" -Dsonar.pullrequest.base="${BRANCH_PR}" -Dsonar.pullrequest.github.repository="bitmovin/${CI_REPO_NAME}"
  echo "Finished pull request analysis for ${CI_BRANCH} with target ${BRANCH_PR} ${PR_NUMBER}"
fi
echo "Finished analysis for ${CI_BRANCH} with target ${BRANCH_PR} ${PR_NUMBER}"
