import {endsWith, isNullOrEmptyString, joinUrls, startsWith} from '../js/utils/Utils';

describe('Utils', () => {
  describe('endsWith', () => {
    // stupid tests that are only here for IE11
    test('it returns true if suffix ends string', () => {
      expect(endsWith('abba', 'ba')).toBeTruthy();
      expect(endsWith('abba', 'a')).toBeTruthy();
      expect(endsWith('abba', 'abba')).toBeTruthy();
    });

    test('it returns false if not matching', () => {
      expect(endsWith('abba', 'c')).toBeFalsy();
    });
  });

  describe('startsWith', () => {
    // stupid tests that are only here for IE11
    test('it returns true if prefix', () => {
      expect(startsWith('abba', 'ab')).toBeTruthy();
      expect(startsWith('abba', 'a')).toBeTruthy();
      expect(startsWith('abba', 'abba')).toBeTruthy();
    });

    test('it returns false if not matching', () => {
      expect(startsWith('abba', 'c')).toBeFalsy();
    });
  });
  describe('joinUrls', () => {
    test('it joins one or more paths', () => {
      const joinedUrl = joinUrls('http://my-domain.com/', '/tutorials', 'test', '/how-to-join');

      expect(joinedUrl).toBe('http://my-domain.com/tutorials/test/how-to-join');
    });
    test('it joins one or more paths with a slash at the end', () => {
      const joinedUrl = joinUrls('http://my-domain.com/', 'tutorials', '/how-to-join/');

      expect(joinedUrl).toBe('http://my-domain.com/tutorials/how-to-join/');
    });
  });

  describe('isBlankString', () => {
    test('returns true for string=null', () => {
      const isBlank = isNullOrEmptyString(null);
      expect(isBlank).toBeTruthy();
    });
    test('returns true for string=undefined', () => {
      const isBlank = isNullOrEmptyString(undefined);
      expect(isBlank).toBeTruthy();
    });
    test('returns true for empty string', () => {
      const isBlank = isNullOrEmptyString('');
      expect(isBlank).toBeTruthy();
    });
    test('returns false for a string with length > 0', () => {
      const isBlank = isNullOrEmptyString('a');
      expect(isBlank).toBeFalsy();
    });
  });
});
