import {Bitmovin8SpeedMeterAdapter} from '../../../js/adapters/internal/Bitmovin8SpeedMeterAdapter';

describe('Bitmovin8SpeedMeterAdapter', () => {
  describe('constructor', () => {
    it('should subscribe to DownloadFinished event on player', () => {
      const mock = {
        on: jest.fn(),
        exports: {
          PlayerEvent: {
            DownloadFinished: 'onDownloadFinished',
          },
        },
      };
      const meterMock = {
        addMeasurement: jest.fn(),
      };

      const adapter = new Bitmovin8SpeedMeterAdapter(mock as any, meterMock as any);
      expect(mock.on).toBeCalledWith('onDownloadFinished', expect.any(Function));
    });
  });

  describe('handleOnDownloadFinishEvent', () => {
    const mock = {
      on: jest.fn(),
      exports: {
        PlayerEvent: {
          DownloadFinished: 'onDownloadFinished',
        },
      },
    };
    const meterMock = {
      addMeasurement: jest.fn(),
    };

    const adapter = new Bitmovin8SpeedMeterAdapter(mock as any, meterMock as any);
    const meter = adapter.getDownloadSpeedMeter();
    it('should ignore unsuccessful requests', () => {
      adapter.handleOnDownloadFinishEvent({
        downloadType: 'media/video',
        success: false,
      });

      expect(meter.addMeasurement).not.toBeCalled();
    });

    it('should ignore audio segments', () => {
      adapter.handleOnDownloadFinishEvent({
        downloadType: 'media/audio',
        success: true,
      });

      expect(meter.addMeasurement).not.toBeCalled();
    });
    it('should call meter.addMeasurement for video segments', () => {
      adapter.handleOnDownloadFinishEvent({
        downloadType: 'media/video',
        success: true,
      });

      expect(meter.addMeasurement).toBeCalled();
    });
  });
});
