import {HlsSpeedMeterAdapter} from '../../../js/adapters/internal/HlsSpeedMeterAdapter';

const getMockHlsPlayer = () => {
  return {
    on: jest.fn(),
    constructor: {
      Events: {
        FRAG_LOADED: 'FRAG_LOADED',
      },
    },
  };
};

const getSpeedMeterMock = () => {
  return {
    addMeasurement: jest.fn(),
  };
};

describe('HlsSpeedMeterAdapter', () => {
  describe('constructor', () => {
    it('should subscribe to fragment events on player', () => {
      const mock = getMockHlsPlayer();
      const meterMock = getSpeedMeterMock();

      const adapter = new HlsSpeedMeterAdapter(mock as any, meterMock as any);
      expect(mock.on).toBeCalledWith('FRAG_LOADED', expect.any(Function));
    });
  });
  describe('handleFragmentLoadedEvent', () => {
    const mock = getMockHlsPlayer();
    const meterMock = getSpeedMeterMock();

    const adapter = new HlsSpeedMeterAdapter(mock as any, meterMock as any);
    const meter = adapter.getDownloadSpeedMeter();

    it('should ignore non-video fragments', () => {
      adapter.handleFragmentLoadedEvent({
        frag: {type: 'audio'},
        stats: {},
        networkDetails: {},
      });

      expect(meter.addMeasurement).not.toBeCalled();
    });
    it('should add a measurement', () => {
      adapter.handleFragmentLoadedEvent({
        frag: {type: 'main'},
        stats: {},
        networkDetails: {},
      });

      expect(meter.addMeasurement).toBeCalled();
    });
  });
});
