import analytics, {Bitmovin8Adapter} from '../../js/core/BitmovinAnalyticsExport';

describe('AnalyticsModule', () => {
  test('name', () => {
    expect(analytics.PlayerModule.name).toEqual('analytics');
  });
  test('module', () => {
    expect(analytics.PlayerModule.module).toMatchObject({
      Analytics: Bitmovin8Adapter,
    });
  });
  describe('hooks', () => {
    test('contains a hook named setup', () => {
      expect(analytics.PlayerModule.hooks.setup).toBeDefined();
    });
    describe('setup', () => {
      test('retrieves player config and calls new Analytics()', () => {
        const player = {
          getConfig: () => ({}),
        };
        const module = {Analytics: jest.fn()};
        return analytics.PlayerModule.hooks.setup(module, player).then(() => {
          expect(module.Analytics).toHaveBeenCalledTimes(1);
          expect(module.Analytics).toHaveBeenLastCalledWith(player);
        });
      });

      test('it tries to instantiate analytics if analytics config is not present', () => {
        const config = {};
        const player = {
          getConfig: jest.fn(() => config),
        };
        const module = {Analytics: jest.fn()};
        return analytics.PlayerModule.hooks.setup(module, player).then(() => {
          expect(module.Analytics).toHaveBeenCalled();
        });
      });

      test('return Promise resolves to return value of module', () => {
        const config = {};
        const player = {
          getConfig: jest.fn(() => config),
        };
        const returnValue = {analytics: 'test'};
        const mod = {Analytics: jest.fn().mockImplementation(() => returnValue)};

        return expect(analytics.PlayerModule.hooks.setup(mod, player)).resolves.toStrictEqual(returnValue);
      });
    });
  });
});
