import {SegmentTracker} from '../../js/core/SegmentTracker';
import {SegmentInfo} from '../../js/types/SegmentInfo';

class SegmentTrackerTest extends SegmentTracker {
  public getSegments(): SegmentInfo[] {
    return this.segments;
  }
}

describe('SegmentTracker', () => {
  describe('addSegment', () => {
    test('it adds a segment to the segments list', () => {
      const tracker = new SegmentTrackerTest();
      tracker.addSegment({
        name: 'segment_01',
        timestamp: 1548945245,
        url: '/videos/segment_01.mp4',
      });

      expect(tracker.getSegments().length).toEqual(1);
    });
  });
  describe('removeSegment', () => {
    test('it removes a segment from the segment list', () => {
      const tracker = new SegmentTrackerTest();
      tracker.addSegment({
        name: 'segment_01',
        timestamp: 1548945245,
        url: '/videos/segment_01.mp4',
      });
      tracker.removeSegment('/videos/segment_01.mp4');

      expect(tracker.getSegments().length).toEqual(0);
    });
    test('it does not remove an unknown segment from the segment list', () => {
      const tracker = new SegmentTrackerTest();
      tracker.addSegment({
        name: 'segment_01',
        timestamp: 1548945245,
        url: '/videos/segment_01.mp4',
      });
      tracker.removeSegment('/videos/segment_00.mp4');

      expect(tracker.getSegments().length).toEqual(1);
    });
  });
  describe('resetSegments', () => {
    test('it clears the segment list', () => {
      const tracker = new SegmentTrackerTest();
      tracker.addSegment({
        name: 'segment_01',
        timestamp: 1548945245,
        url: '/videos/segment_01.mp4',
      });
      tracker.reset();

      expect(tracker.getSegments().length).toEqual(0);
    });
  });
});
