import VideoCompletionTracker from '../../js/core/VideoCompletionTracker';
import Timespan from '../../js/types/Timespan';

describe('VideoCompletionTracker', () => {
  test('addWatched should return correct value when no overlapping occurs', () => {
    const videoDuration = 10;
    const tracker = new VideoCompletionTracker();
    tracker.setVideoDuration(videoDuration);
    const watched: Timespan = {start: 0, end: 2000};
    const watched2: Timespan = {start: 3000, end: 5000};
    const addedWatched = tracker.addWatched(watched);
    expect(addedWatched).toEqual(0.2);
    expect(tracker.getCompletionPercentage()).toEqual(0.2);

    const addedWatched2 = tracker.addWatched(watched2);
    expect(addedWatched2).toEqual(0.2);
    expect(tracker.getCompletionPercentage()).toEqual(0.4);
  });

  test('addWatched should return correct value when overlapping occurs', () => {
    const videoDuration = 10;
    const tracker = new VideoCompletionTracker();
    tracker.setVideoDuration(videoDuration);
    const watched: Timespan = {start: 0, end: 2000};
    const watched2: Timespan = {start: 1000, end: 3000};
    const addedWatched = tracker.addWatched(watched);
    expect(addedWatched).toEqual(0.2);
    expect(tracker.getCompletionPercentage()).toEqual(0.2);

    const addedWatched2 = tracker.addWatched(watched2);
    expect(addedWatched2).toEqual(0.1);
    expect(tracker.getCompletionPercentage()).toEqual(0.3);
  });

  test('addWatched should return correct value when containing occurs', () => {
    const videoDuration = 10;
    const tracker = new VideoCompletionTracker();
    tracker.setVideoDuration(videoDuration);
    const watched: Timespan = {start: 1000, end: 2000};
    const watched2: Timespan = {start: 0, end: 3000};
    const addedWatched = tracker.addWatched(watched);
    expect(addedWatched).toEqual(0.1);
    expect(tracker.getCompletionPercentage()).toEqual(0.1);

    const addedWatched2 = tracker.addWatched(watched2);
    expect(addedWatched2).toEqual(0.2);
    expect(tracker.getCompletionPercentage()).toEqual(0.3);
  });

  test('addWatched should return correct value when wrapping occurs', () => {
    const videoDuration = 10;
    const tracker = new VideoCompletionTracker();
    tracker.setVideoDuration(videoDuration);
    const watched: Timespan = {start: 0, end: 3000};
    const watched2: Timespan = {start: 1000, end: 2000};
    const addedWatched = tracker.addWatched(watched);
    expect(addedWatched).toEqual(0.3);
    expect(tracker.getCompletionPercentage()).toEqual(0.3);

    const addedWatched2 = tracker.addWatched(watched2);
    expect(addedWatched2).toEqual(0);
    expect(tracker.getCompletionPercentage()).toEqual(0.3);
  });

  test('addWatched should return correct value when multiple overlapping occurs', () => {
    const videoDuration = 10;
    const tracker = new VideoCompletionTracker();
    tracker.setVideoDuration(videoDuration);
    const watched: Timespan = {start: 0, end: 2000};
    const watched2: Timespan = {start: 3000, end: 5000};
    const watched3: Timespan = {start: 1000, end: 4000};
    tracker.addWatched(watched);
    tracker.addWatched(watched2);
    const addedWatched = tracker.addWatched(watched3);
    expect(addedWatched).toEqual(0.1);
    expect(tracker.getCompletionPercentage()).toEqual(0.5);
  });

  test('addWatched should return correct value when multiple containing occurs', () => {
    const videoDuration = 10;
    const tracker = new VideoCompletionTracker();
    tracker.setVideoDuration(videoDuration);
    const watched: Timespan = {start: 1000, end: 2000};
    const watched2: Timespan = {start: 3000, end: 4000};
    const watched3: Timespan = {start: 0, end: 5000};
    tracker.addWatched(watched);
    tracker.addWatched(watched2);
    const addedWatched = tracker.addWatched(watched3);
    expect(addedWatched).toEqual(0.3);
    expect(tracker.getCompletionPercentage()).toEqual(0.5);
  });
});
