import {InternalAdapterAPI} from '../../js/adapters/internal/InternalAdapterAPI';
import {AnalyticsStateMachine} from '../../js/analyticsStateMachines/AnalyticsStateMachine';
import {EventDispatcher} from '../../js/core/EventDispatcher';
import VideoCompletionTracker from '../../js/core/VideoCompletionTracker';
import {DrmPerformanceInfo} from '../../js/types/DrmPerformanceInfo';
import {defaultStateMachineCallbacks, StateMachineCallbacks} from '../../js/types/StateMachineCallbacks';
import {getCurrentTimestamp} from '../../js/utils/Utils';

export class MockInternalAdapterApi implements InternalAdapterAPI {
  public videoCompletionTracker: VideoCompletionTracker = new VideoCompletionTracker();

  private _qualityChangeCounter: number = 0;
  private readonly qualityChangeThreshold: number;

  constructor(public stateMachine?: AnalyticsStateMachine) {
    this.stateMachine = stateMachine;
    this.qualityChangeThreshold = 2;
  }

  get drmPerformanceInfo() {
    return {
      drmUsed: false,
    };
  }
  get downloadSpeedInfo() {
    return {
      segmentsDownloadCount: 0,
      segmentsDownloadSize: 0,
      segmentsDownloadTime: 0,
      minDownloadSpeed: 0,
      maxDownloadSpeed: 0,
      avgDownloadSpeed: 0,
      avgTimeToFirstByte: 0,
    };
  }
  get segments() {
    return [];
  }

  get onLicenseKeyReceived(): EventDispatcher<{licenseKey: string}> {
    return new EventDispatcher();
  }
  get onLicenseCallFailed(): EventDispatcher<{}> {
    return new EventDispatcher();
  }

  get supportsDeferredLicenseLoading() {
    return true;
  }

  get qualityChangeCounter() {
    return this._qualityChangeCounter;
  }

  public eventCallback = (eventType: string, eventObject: any) => {
    eventObject = eventObject || {};
    if (!this.stateMachine) {
    } else {
      this.stateMachine.callEvent(eventType, eventObject, getCurrentTimestamp());
    }
  };

  public isQualityChangeEventEnabled(): boolean {
    return this.qualityChangeCounter <= this.qualityChangeThreshold;
  }

  public increaseQualityChangeCount(): void {
    this._qualityChangeCounter++;
  }

  public resetQualityChangeCount(): void {
    this._qualityChangeCounter = 0;
  }

  public stateMachineCallbacks: StateMachineCallbacks = {...defaultStateMachineCallbacks};

  public getPlayerVersion() {
    return '';
  }
  public getPlayerName() {
    return '';
  }
  public getPlayerTech() {
    return '';
  }
  public getAutoPlay() {
    return false;
  }
  public getDrmPerformanceInfo(): DrmPerformanceInfo | undefined {
    return undefined;
  }
  public getCurrentPlaybackInfo() {
    return {
      droppedFrames: 0,
    };
  }
  public sourceChange(config: any, timestamp: number) {}
  public clearValues() {}
  public initialize() {}
}
