import {Bitmovin8AnalyticsStateMachine} from '../../js/analyticsStateMachines/Bitmovin8AnalyticsStateMachine';
import {AnalyticsStateMachineOptions} from '../../js/types/AnalyticsStateMachineOptions';
import {StateMachineCallbacks} from '../../js/types/StateMachineCallbacks';
import {ANALYTICS_REBUFFER_TIMEOUT, ANALYTICS_VIDEOSTART_TIMEOUT} from '../../js/utils/Settings';

export interface AnalyticsStateMachineTweaks {
  videoStartupTimeoutMs: number;
  rebufferTimeoutMs: number;
}

export const defaultStateMachineTweaks: AnalyticsStateMachineTweaks = {
  videoStartupTimeoutMs: ANALYTICS_VIDEOSTART_TIMEOUT,
  rebufferTimeoutMs: ANALYTICS_REBUFFER_TIMEOUT,
};

export class MockedBitmovin8StateMachine extends Bitmovin8AnalyticsStateMachine {
  protected readonly videoStartupTimeoutMs: number;
  protected readonly rebufferTimeoutMs: number;

  constructor(
    stateMachineCallbacks: StateMachineCallbacks,
    opts: AnalyticsStateMachineOptions,
    tweaks: Partial<AnalyticsStateMachineTweaks> = defaultStateMachineTweaks
  ) {
    super(stateMachineCallbacks, opts);

    const tweaksAndDefaults: AnalyticsStateMachineTweaks = {...defaultStateMachineTweaks, ...tweaks};
    this.videoStartupTimeoutMs = tweaksAndDefaults.videoStartupTimeoutMs;
    this.rebufferTimeoutMs = tweaksAndDefaults.rebufferTimeoutMs;
  }

  public getCurrentState(): string {
    return this.stateMachine.current;
  }
}
